@@ -17,6 +17,14 @@ parser.add_argument('value')
 class FEs(Resource):
     def post(self, project_id, fm_id):
         args = parser.parse_args()
+        existing_fe = FeatureEvaluations.query.filter_by(
+            fm_id=fm_id,
+            feature_id=args["feature_id"],
+            metric_id=args["metric_id"]
+        ).first()
+        if existing_fe:
+            db.session.delete(existing_fe)
+            db.session.commit()
         new_fe = FeatureEvaluations(
             fm_id=fm_id,
             feature_id=args["feature_id"],
